==> vue-sb-components-2.1.5.tgz: package/components/menu/menu.js <==
import "./menu.css";
import { defineComponent as d, resolveComponent as c, openBlock as s, createElementBlock as a, Fragment as u, createElementVNode as m, createVNode as f, mergeProps as g, withModifiers as v, withCtx as S, renderSlot as p, createTextVNode as y, toDisplayString as w, createBlock as $, Teleport as P, normalizeStyle as b, createCommentVNode as W } from "vue";
import _ from "../button/button.js";
import { r as h } from "../../helper-4d4ed314.js";
import { _ as C } from "../../_plugin-vue_export-helper-dad06003.js";
import "../tooltip/tooltip.js";
const k = d({
  emits: {
    change: (e) => !0
  },
  props: {
    color: {
      default: "default",
      type: String
    },
    disabled: {
      default: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    noElevation: {
      required: !1,
      type: Boolean
    },
    open: {
      required: !0,
      type: Boolean
    },
    size: {
      default: "base",
      type: String
    },
    tooltip: {
      required: !1,
      type: String
    },
    variant: {
      default: "contained",
      type: String
    }
  },
  name: "sb-menu",
  components: {
    "sb-button": _
  },
  data() {
    return {
      localOpen: !1,
      itemsWrapperStyles: [],
      parentWithScroll: null
    };
  },
  methods: {
    handleClose(e) {
      const o = e.target, t = this.$refs["menu-wrapper"];
      o && t && !t.contains(o) && !o.isSameNode(t) && this.$emit("change", !1);
    },
    handleOpen() {
      this.disabled || (this.localOpen = !0, this.$emit("change", !0), this.$nextTick(() => {
        this.setPopupPosition();
      }));
    },
    handleParentScroll(e) {
      const o = h(this.$el);
      this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
        this.setPopupPosition();
      }), o && (e ? o.addEventListener("scroll", () => {
        this.setPopupPosition();
      }) : o.removeEventListener("scroll", () => {
        this.setPopupPosition();
      })), this.$nextTick(() => {
        this.parentWithScroll = o;
      });
    },
    setPopupPosition() {
      var o;
      const e = this.$refs["menu-wrapper"];
      if (e) {
        const t = e.getBoundingClientRect(), i = (o = this.$refs["menu-items-wrapper"]) == null ? void 0 : o.getBoundingClientRect(), n = () => t.width < i.width ? t.x + (t.width - i.width) / 2 : t.x;
        if (i) {
          const r = t.width > i.width ? t.width : i.width;
          return document.body.getBoundingClientRect().height - (t.height + t.y) <= i.height ? this.itemsWrapperStyles = {
            left: `${n()}px`,
            top: `${t.y - 6 - i.height}px`,
            width: `${r}px`
          } : this.itemsWrapperStyles = {
            left: `${n()}px`,
            top: `${t.y + t.height}px`,
            width: `${r}px`
          };
        }
      }
    }
  },
  watch: {
    open(e) {
      this.localOpen = e;
    },
    localOpen(e) {
      this.handleParentScroll(e);
    }
  },
  mounted() {
    this.setPopupPosition(), document.addEventListener(
      "click",
      (e) => this.handleClose(e)
    ), this.parentWithScroll = h(this.$el);
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClose(e)
    ), this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
      this.setPopupPosition();
    });
  }
});
const B = {
  class: "menu-wrapper",
  ref: "menu-wrapper"
};
function E(e, o, t, i, n, r) {
  const l = c("sb-button");
  return s(), a(u, null, [
    m("div", B, [
      f(l, g({
        "no-elevation": e.localOpen || e.noElevation
      }, {
        color: e.color,
        disabled: e.disabled,
        size: e.size,
        tooltip: e.tooltip,
        variant: e.variant
      }, {
        onClick: v(e.handleOpen, ["stop"])
      }), {
        default: S(() => [
          p(e.$slots, "slot-label", {}, () => [
            y(w(e.label || "..."), 1)
          ], !0)
        ]),
        _: 3
      }, 16, ["no-elevation", "onClick"])
    ], 512),
    (s(), $(P, { to: "body" }, [
      e.localOpen ? (s(), a("div", {
        key: 0,
        class: "menu-items-wrapper",
        ref: "menu-items-wrapper",
        style: b(e.itemsWrapperStyles)
      }, [
        p(e.$slots, "default", {}, void 0, !0)
      ], 4)) : W("", !0)
    ]))
  ], 64);
}
const z = /* @__PURE__ */ C(k, [["render", E], ["__scopeId", "data-v-68c4a48e"]]);
export {
  z as default
};

==> vue-sb-components-2.1.14.tgz: package/components/menu/menu.js <==
import "./menu.css";
import { defineComponent as c, resolveComponent as u, openBlock as s, createElementBlock as a, Fragment as m, createElementVNode as f, mergeProps as p, createVNode as v, withModifiers as S, withCtx as y, renderSlot as d, createTextVNode as g, toDisplayString as w, createBlock as $, Teleport as b, normalizeStyle as P, createCommentVNode as W } from "vue";
import C from "../button/button.js";
import { r as h } from "../../helper-4d4ed314.js";
import { _ as k } from "../../_plugin-vue_export-helper-dad06003.js";
import "../tooltip/tooltip.js";
const B = c({
  props: {
    color: {
      default: "default",
      type: String
    },
    disabled: {
      default: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    noElevation: {
      required: !1,
      type: Boolean
    },
    open: {
      required: !0,
      type: Boolean
    },
    size: {
      default: "base",
      type: String
    },
    tooltip: {
      required: !1,
      type: String
    },
    variant: {
      default: "contained",
      type: String
    }
  },
  name: "sb-menu",
  components: {
    "sb-button": C
  },
  data() {
    return {
      localOpen: !1,
      itemsWrapperStyles: [],
      parentWithScroll: null
    };
  },
  methods: {
    handleClose(e) {
      const o = e.target, t = this.$refs["menu-wrapper"];
      o && t && !t.contains(o) && !o.isSameNode(t) && (this.localOpen = !1);
    },
    handleOpen() {
      this.disabled || (this.localOpen = !0, this.$nextTick(() => {
        this.setPopupPosition();
      }));
    },
    handleParentScroll(e) {
      const o = h(this.$el);
      this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
        this.setPopupPosition();
      }), o && (e ? o.addEventListener("scroll", () => {
        this.setPopupPosition();
      }) : o.removeEventListener("scroll", () => {
        this.setPopupPosition();
      })), this.$nextTick(() => {
        this.parentWithScroll = o;
      });
    },
    setPopupPosition() {
      var o;
      const e = this.$refs["menu-wrapper"];
      if (e) {
        const t = e.getBoundingClientRect(), i = (o = this.$refs["menu-items-wrapper"]) == null ? void 0 : o.getBoundingClientRect(), n = () => t.width < i.width ? t.x + (t.width - i.width) / 2 : t.x;
        if (i) {
          const r = t.width > i.width ? t.width : i.width;
          return document.body.getBoundingClientRect().height - (t.height + t.y) <= i.height ? this.itemsWrapperStyles = {
            left: `${n()}px`,
            top: `${t.y - 6 - i.height}px`,
            width: `${r}px`
          } : this.itemsWrapperStyles = {
            left: `${n()}px`,
            top: `${t.y + t.height}px`,
            width: `${r}px`
          };
        }
      }
    }
  },
  watch: {
    localOpen(e) {
      this.handleParentScroll(e);
    }
  },
  mounted() {
    this.localOpen = this.open, this.$nextTick(() => this.setPopupPosition()), document.addEventListener(
      "click",
      (e) => this.handleClose(e)
    ), this.parentWithScroll = h(this.$el);
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClose(e)
    ), this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
      this.setPopupPosition();
    });
  }
});
function E(e, o, t, i, n, r) {
  const l = u("sb-button");
  return s(), a(m, null, [
    f("div", p({
      class: "menu-wrapper",
      ref: "menu-wrapper"
    }, { ...e.$attrs }), [
      v(l, p({
        "no-elevation": e.localOpen || e.noElevation
      }, {
        color: e.color,
        disabled: e.disabled,
        size: e.size,
        tooltip: e.tooltip,
        variant: e.variant
      }, {
        onClick: S(e.handleOpen, ["stop"])
      }), {
        default: y(() => [
          d(e.$slots, "slot-label", {}, () => [
            g(w(e.label || "..."), 1)
          ], !0)
        ]),
        _: 3
      }, 16, ["no-elevation", "onClick"])
    ], 16),
    (s(), $(b, { to: "body" }, [
      e.localOpen ? (s(), a("div", {
        key: 0,
        class: "menu-items-wrapper",
        ref: "menu-items-wrapper",
        style: P(e.itemsWrapperStyles)
      }, [
        d(e.$slots, "default", {}, void 0, !0)
      ], 4)) : W("", !0)
    ]))
  ], 64);
}
const q = /* @__PURE__ */ k(B, [["render", E], ["__scopeId", "data-v-806948ab"]]);
export {
  q as default
};
